==> spip_3.2.11.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Actualizar todos os URLs',
	'actualiser_toutes_explication' => 'Pode re-calcular os URLs.
Se um URL mudou, uma nova entrada será criada (sem perder os URLs já presentes e sem os URLs definidos manualmente).', # MODIF

	// B
	'bouton_supprimer_url' => 'Eliminar este URL',

	// E
	'erreur_arbo_2_segments_max' => 'Não pode usar mais de dois segmentos  URL para um objecto.',
	'erreur_config_url_forcee' => 'A configuração dos URLs está fixada no ficheiro <tt>mes_options.php</tt>.',
	'explication_editer' => 'A gestão avançada de URLs permite editar o URL das páginas de cada objecto editorial, e gerir o histórico da sua evolução.',

	// I
	'icone_configurer_urls' => 'Configurar os URLs',
	'icone_controler_urls' => 'URLs significativos',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Objecto',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Novo URL',
	'label_url_minuscules_0' => 'Conservar maiúsculas/minúsculas do título',
	'label_url_minuscules_1' => 'Forçar os urls em minúsculas',
	'label_url_permanente' => 'Bloquear este URL (sem actualizações após a modificação do objecto)',
	'label_url_sep_id' => 'Caracter para separar o número adicionado em caso de duplicado',
	'label_urls_activer_controle_oui' => 'Activar a gestão avançada de URLs',
	'label_urls_nb_max_car' => 'Número máximo de caracteres',
	'label_urls_nb_min_car' => 'Número mínimo de caracteres',
	'liberer_url' => 'Lançar',
	'liste_des_urls' => 'Todos os URLs',

	// T
	'texte_type_urls' => 'Pode escolher como os URLs das páginas serão calculados.',
	'texte_type_urls_attention' => 'Atenção: esta opção apenas funcionará se o ficheiro @htaccess@ estiver correctamente instalado no directório raiz do seu sítio.',
	'texte_urls_nb_max_car' => 'Se o título é mais longo, será cortado.',
	'texte_urls_nb_min_car' => 'Se o título for demasiado curto, o número de identificação será utilizado.',
	'titre_gestion_des_urls' => 'Gestão dos URLs',
	'titre_type_arbo' => 'URLs Arborescentes',
	'titre_type_html' => 'URLs Objectos HTML',
	'titre_type_libres' => 'URLs Livres',
	'titre_type_page' => 'Página URLs ',
	'titre_type_propres' => 'URLs Limpos',
	'titre_type_propres2' => 'URLs Limpos+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Limpos em query-string',
	'titre_type_simple' => 'URLs Simples',
	'titre_type_standard' => 'URLs Históricos',
	'titre_type_urls' => 'Tipo de endereços URL',
	'tout_voir' => 'Ver todos os URLs',

	// U
	'url_ajout_impossible' => 'Ocorreu um erro. Este URL não pôde ser guardado.',
	'url_ajoutee' => 'O URL foi adicionado',

	// V
	'verifier_url_nettoyee' => 'O URL foi corrigido. Pode verificar antes de guardar.',
	'verrouiller_url' => 'Bloquear'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'Actualizar todos os URLs',
	'actualiser_toutes_explication' => 'Pode re-calcular os URLs.
Se um URL mudou, uma nova entrada será criada (sem perder os URLs já presentes e sem os URLs definidos manualmente).', # MODIF

	// B
	'bouton_supprimer_url' => 'Eliminar este URL',

	// E
	'erreur_arbo_2_segments_max' => 'Não pode usar mais de dois segmentos  URL para um objecto.',
	'erreur_config_url_forcee' => 'A configuração dos URLs está fixada no ficheiro <tt>mes_options.php</tt>.',
	'explication_editer' => 'A gestão avançada de URLs permite editar o URL das páginas de cada objecto editorial, e gerir o histórico da sua evolução.',

	// I
	'icone_configurer_urls' => 'Configurar os URLs',
	'icone_controler_urls' => 'URLs significativos',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Objecto',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Novo URL',
	'label_url_minuscules_0' => 'Conservar maiúsculas/minúsculas do título',
	'label_url_minuscules_1' => 'Forçar os urls em minúsculas',
	'label_url_permanente' => 'Bloquear este URL (sem actualizações após a modificação do objecto)',
	'label_url_sep_id' => 'Caracter para separar o número adicionado em caso de duplicado',
	'label_urls_activer_controle_oui' => 'Activar a gestão avançada de URLs',
	'label_urls_nb_max_car' => 'Número máximo de caracteres',
	'label_urls_nb_min_car' => 'Número mínimo de caracteres',
	'liberer_url' => 'Lançar',
	'liste_des_urls' => 'Todos os URLs',

	// T
	'texte_type_urls' => 'Pode escolher como os URLs das páginas serão calculados.',
	'texte_type_urls_attention' => 'Atenção: esta opção apenas funcionará se o ficheiro @htaccess@ estiver correctamente instalado no directório raiz do seu sítio.',
	'texte_urls_nb_max_car' => 'Se o título é mais longo, será cortado.',
	'texte_urls_nb_min_car' => 'Se o título for demasiado curto, o número de identificação será utilizado.',
	'titre_gestion_des_urls' => 'Gestão dos URLs',
	'titre_type_arbo' => 'URLs Arborescentes',
	'titre_type_html' => 'URLs Objectos HTML',
	'titre_type_libres' => 'URLs Livres',
	'titre_type_page' => 'Página URLs ',
	'titre_type_propres' => 'URLs Limpos',
	'titre_type_propres2' => 'URLs Limpos+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Limpos em query-string',
	'titre_type_simple' => 'URLs Simples',
	'titre_type_standard' => 'URLs Históricos',
	'titre_type_urls' => 'Tipo de endereços URL',
	'tout_voir' => 'Ver todos os URLs',

	// U
	'url_ajout_impossible' => 'Ocorreu um erro. Este URL não pôde ser guardado.',
	'url_ajoutee' => 'O URL foi adicionado',

	// V
	'verifier_url_nettoyee' => 'O URL foi corrigido. Pode verificar antes de guardar.',
	'verrouiller_url' => 'Bloquear',
];
